@@ -12,7 +12,7 @@ our $DEBUG && (*DEBUG = *STDERR);
 our $SHELL = 'sh';
 our $CHDIR = 0;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our @EXPORT_OK = qw(system readpipe qx backticks source
                     readpipe_list qx_list backticks_list);
 my @readpipe_exp = qw(readpipe readpipe_list qx_list backticks_list);
@@ -20,7 +20,8 @@ our %EXPORT_TAGS = ('system' => ['system'],
                     'readpipe' => [@readpipe_exp],
                     'qx' => ['qx','backticks', @readpipe_exp],
                     'backticks' => ['qx','backticks', @readpipe_exp],
-                    'all' => ['system', 'qx','backticks', 'source', @readpipe_exp],
+                    'all' => [ 'system', 'qx','backticks', 'source',
+                               @readpipe_exp],
                     'chdir' => [],
                     'sh' => [], 'bash' => [], 'csh' => [], 'dash' => [],
                     'ksh' => [], 'tcsh' => [], 'zsh' => [] );
@@ -59,7 +60,7 @@ sub import {
         };
         $cgreadpipe = 1;
     } elsif ($tags{":readpipe"}) {
-        # CORE::GLOBAL::readpipe will not be respected for Perl <v5.8.9
+        # NB: CORE::GLOBAL::readpipe will not be respected for Perl <=v5.8.9
         *CORE::GLOBAL::readpipe = sub {
             local $_RT115330 = 0;
             return _readpipe_mod_env(@_);
@@ -92,8 +93,10 @@ sub import {
 
 sub backticks {goto &readpipe }
 sub qx { goto &readpipe }
+
 sub backticks_list { goto &readpipe_list }
 sub qx_list { goto &readpipe_list }
+
 sub readpipe {
     local $_RT115330 = 0;
     return _readpipe_mod_env(@_);
@@ -263,7 +266,7 @@ Env::Modify - affect Perl %ENV from subshell
 
 =head1 VERSION
 
-0.01
+0.02
 
 =head1 SYNOPSIS
 
